@@ -10,11 +10,11 @@ FSM::Basic -  Finite state machine using HASH as state definitions
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -106,50 +106,50 @@ The keys are the states name.
 
 =over 4
 
-=item *
+=item * 
 "cat" just reading the file content provided in parameter).
 
-=item *
+=item * 
 "catRAND" chose randomly one of the files provided in parameter space separated
 
-=item *
-"catSEQ" read sequentialy the next files provided in parameter space separated
-        if "catSEQ_idx" is defined, that file is used to keep the state. Otherwise , the state file is named used
-        all the files name from "catSEQ" concatenated with a final '.tate'. All spaces are replaced by an underscore
+=item * 
+"catSEQ" read sequentialy the next files provided in parameter space separated 
+        if "catSEQ_idx" is defined, that file is used to keep the state. Otherwise , the state file is named used 
+        all the files name from "catSEQ" concatenated with a final '.tate'. All spaces are replaced by an underscore 
 
 =back
 
-=item
+=item 
 
 "matching" to define the state when the input match the "expect" value
 
 
-=item
+=item 
 
 "final" to return a flag
 
 
-=item
+=item 
 
 "not_matching" the state if the input is not matching the "expect" value (if missing stay in the same state)
 
 
-=item
+=item 
 
 "repeat" a number of trial before the state goes to "not_matching0"
 
 
-=item
+=item 
 
 "not_matching0" the state when the number of failled matching number is reached
 
 
-=item
+=item 
 
 "not_matching_info_last" info returned as second value when the  failled matching number is reached
 
 
-=item
+=item 
 
 "output" the info  returned as second value
 
@@ -278,7 +278,7 @@ sub run {
                     }else{
                     $state_file = $old_cat . '.state';
                     $state_file =~ s/\s/_/g;
-
+                    
                      }
                     $state->{catSEQ} =~ s/__IN__/$in/g;
                     my @files = split /\s+/, $state->{catSEQ};
@@ -320,7 +320,7 @@ sub set {
 
 sub write_file {
     my ($file, $content) = @_;
-    open my $fh, ">$file" or die "Error opening file for write $file: $!\n";
+    open my $fh, '>' , $file or die "Error opening file for write $file: $!\n";
     print $fh $content;
     close $fh or die "Error closing file $file: $!\n";
 }
